pub trait DenseVectorMut: DenseVector {
// Required method
fn index_mut(&mut self, idx: usize) -> &mut Self::Scalar;
}Expand description
Trait for dense vectors that can be modified, useful for expressing algorithms which compute a resulting dense vector, such as solvers.
This trait is sealed, and cannot be implemented outside of the sprs
crate.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.