Structs
- CsVec
Base - A sparse vector, storing the indices of its non-zero data.
- NnzIndex
- Hold the index of a non-zero element in the compressed storage
- NnzOr
Zip - An iterator over the non zeros of either of two vector iterators, ordered, such that the sum of the vectors may be computed
- Vector
Iterator - An iterator over the non-zero elements of a sparse vector
- Vector
Iterator Mut - An iterator over the mutable non-zero elements of a sparse vector
Enums
Traits
- Into
Sparse VecIter - Trait for types that can be iterated as sparse vectors
- Sparse
Iter Tools - VecDim
- A trait to represent types which can be interpreted as vectors of a given dimension.